==> var-sd-card-writer-0.0.1.tar.gz: var-sd-card-writer-0.0.1/writer/_information.py <==
# Copyright 2022 Variscite LTD
# SPDX-License-Identifier: BSD-3-Clause

"""
Information file.
"""

import re
import sys


COMMENTS = "SD Card Writer Tool"
COPYRIGHT = "Copyright 2022 Variscite LTD"
AUTHORS = ["Alifer Moraes", "Diego Dorta"]
PROGRAM_NAME = "Variscite SD Card Writer Tool"

VERSION_FILE = "_version.py"
VERSION = "Unknown"
try:
    verstrline = open(VERSION_FILE, "rt").read()
except EnvironmentError:
    pass
else:
    VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
    mo = re.search(VSRE, verstrline, re.M)
    if mo:
        VERSION = mo.group(1)
    else:
        sys.exit(f"Unable to find version in {VERSION_FILE}")

WEBSITE = "https://github.com/varigit/var-sd-card-writer"
WEBSITE_LABEL = "SD Card Writer on GitHub"

LICENSE = (
    f"Redistribution and use in source and binary forms, with or without\n"
    f"modification, are permitted provided that the following conditions are met:\n\n"
    f"1. Redistributions of source code must retain the above copyright notice, this\n"
    f"list of conditions and the following disclaimer.\n\n"
    f"2. Redistributions in binary form must reproduce the above copyright notice,\n"
    f"this list of conditions and the following disclaimer in the documentation\n"
    f"and/or other materials provided with the distribution.\n\n"
    f"3. Neither the name of the copyright holder nor the names of its\n"
    f"contributors may be used to endorse or promote products derived from\n"
    f"this software without specific prior written permission.\n\n"
    f"THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\"\n"
    f"AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\n"
    f"IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE\n"
    f"DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE\n"
    f"FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL\n"
    f"DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR\n"
    f"SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER\n"
    f"CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,\n"
    f"OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE\n"
    f"OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n")

==> var-sd-card-writer-0.0.3.tar.gz: var-sd-card-writer-0.0.3/writer/_information.py <==
# Copyright 2022 Variscite LTD
# SPDX-License-Identifier: BSD-3-Clause

"""
Information file.
"""

COMMENTS = "Flash the latest OS images to SD cards, safely and easily"
COPYRIGHT = "Copyright 2022 Variscite LTD"
AUTHORS = ["Alifer Moraes", "Diego Dorta"]
PROGRAM_NAME = "SD Card Writer Tool"
WEBSITE = "https://github.com/varigit/var-sd-card-writer"
WEBSITE_LABEL = "SD Card Writer on GitHub"

LICENSE = (
    f"Redistribution and use in source and binary forms, with or without\n"
    f"modification, are permitted provided that the following conditions are met:\n\n"
    f"1. Redistributions of source code must retain the above copyright notice, this\n"
    f"list of conditions and the following disclaimer.\n\n"
    f"2. Redistributions in binary form must reproduce the above copyright notice,\n"
    f"this list of conditions and the following disclaimer in the documentation\n"
    f"and/or other materials provided with the distribution.\n\n"
    f"3. Neither the name of the copyright holder nor the names of its\n"
    f"contributors may be used to endorse or promote products derived from\n"
    f"this software without specific prior written permission.\n\n"
    f"THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\"\n"
    f"AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\n"
    f"IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE\n"
    f"DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE\n"
    f"FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL\n"
    f"DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR\n"
    f"SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER\n"
    f"CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,\n"
    f"OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE\n"
    f"OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n")
